package v3client
import "go.etcd.io/etcd/server/v3/etcdserver/api/v3client"
Package v3client provides clientv3 interfaces from an etcdserver.
Use v3client by creating an EtcdServer instance, then wrapping it with v3client.New:
import (
"context"
"go.etcd.io/etcd/server/v3/embed"
"go.etcd.io/etcd/server/v3/etcdserver/api/v3client"
)
...
// create an embedded EtcdServer from the default configuration
cfg := embed.NewConfig()
cfg.Dir = "default.etcd"
e, err := embed.StartEtcd(cfg)
if err != nil {
// handle error!
}
// wrap the EtcdServer with v3client
cli := v3client.New(e.Server)
// use like an ordinary clientv3
resp, err := cli.Put(context.TODO(), "some-key", "it works!")
if err != nil {
// handle error!
}
Index ¶
Functions ¶
func New ¶
func New(s *etcdserver.EtcdServer) *clientv3.Client
New creates a clientv3 client that wraps an in-process EtcdServer. Instead of making gRPC calls through sockets, the client makes direct function calls to the etcd server through its api/v3rpc function interfaces.
Source Files ¶
doc.go v3client.go
- Version
- v3.7.1 (latest)
- Published
- Jul 23, 2026
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 4 hours ago –
Tools for package owners.