package gw

import "go.etcd.io/etcd/server/v3/etcdserver/api/v3election/v3electionpb/gw"

Package v3electionpb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Functions

func RegisterElectionHandler

func RegisterElectionHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterElectionHandler registers the http handlers for service Election to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterElectionHandlerClient

func RegisterElectionHandlerClient(ctx context.Context, mux *runtime.ServeMux, client v3electionpb.ElectionClient) error

v3electionpb.RegisterElectionHandlerClient registers the http handlers for service Election to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "ElectionClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "ElectionClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "ElectionClient" to call the correct interceptors. This client ignores the HTTP middlewares.

func RegisterElectionHandlerFromEndpoint

func RegisterElectionHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterElectionHandlerFromEndpoint is same as RegisterElectionHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterElectionHandlerServer

func RegisterElectionHandlerServer(ctx context.Context, mux *runtime.ServeMux, server v3electionpb.ElectionServer) error

v3electionpb.RegisterElectionHandlerServer registers the http handlers for service Election to "mux". UnaryRPC :call v3electionpb.ElectionServer directly. StreamingRPC :currently unsupported pending https://github.com/grpc/grpc-go/issues/906. Note that using this registration option will cause many gRPC library features to stop working. Consider using RegisterElectionHandlerFromEndpoint instead. GRPC interceptors will not work for this type of registration. To use interceptors, you must use the "runtime.WithMiddlewares" option in the "runtime.NewServeMux" call.

Source Files

v3election.pb.gw.go

Version
v3.7.1 (latest)
Published
Jul 23, 2026
Platform
linux/amd64
Imports
13 packages
Last checked
5 hours ago

Tools for package owners.