package features
import "go.etcd.io/etcd/server/v3/features"
Index ¶
- Constants
- Variables
- func NewDefaultServerFeatureGate(name string, lg *zap.Logger) featuregate.FeatureGate
Constants ¶
const ( // StopGRPCServiceOnDefrag enables etcd gRPC service to stop serving client requests on defragmentation. // owner: @chaochn47 // alpha: v3.6 // main PR: https://github.com/etcd-io/etcd/pull/18279 StopGRPCServiceOnDefrag featuregate.Feature = "StopGRPCServiceOnDefrag" // TxnModeWriteWithSharedBuffer enables the write transaction to use a shared buffer in its readonly check operations. // owner: @wilsonwang371 // beta: v3.5 // main PR: https://github.com/etcd-io/etcd/pull/12896 featuregate.Feature = "TxnModeWriteWithSharedBuffer" // InitialCorruptCheck enable to check data corruption before serving any client/peer traffic. // owner: @serathius // alpha: v3.6 // main PR: https://github.com/etcd-io/etcd/pull/10524 InitialCorruptCheck featuregate.Feature = "InitialCorruptCheck" // CompactHashCheck enables leader to periodically check followers compaction hashes. // owner: @serathius // alpha: v3.6 // main PR: https://github.com/etcd-io/etcd/pull/14120 CompactHashCheck featuregate.Feature = "CompactHashCheck" // LeaseCheckpoint enables leader to send regular checkpoints to other members to prevent reset of remaining TTL on leader change. // owner: @serathius // alpha: v3.6 // main PR: https://github.com/etcd-io/etcd/pull/13508 LeaseCheckpoint featuregate.Feature = "LeaseCheckpoint" // LeaseCheckpointPersist enables persisting remainingTTL to prevent indefinite auto-renewal of long lived leases. Always enabled in v3.6. Should be used to ensure smooth upgrade from v3.5 clusters with this feature enabled. // Requires EnableLeaseCheckpoint featuragate to be enabled. // TODO: Delete in v3.7 // owner: @serathius // alpha: v3.6 // main PR: https://github.com/etcd-io/etcd/pull/13508 // Deprecated: Enabled by default in v3.6, to be removed in v3.7. LeaseCheckpointPersist featuregate.Feature = "LeaseCheckpointPersist" // SetMemberLocalAddr enables using the first specified and non-loopback local address from initial-advertise-peer-urls as the local address when communicating with a peer. // Requires SetMemberLocalAddr featuragate to be enabled. // owner: @flawedmatrix // alpha: v3.6 // main PR: https://github.com/etcd-io/etcd/pull/17661 SetMemberLocalAddr featuregate.Feature = "SetMemberLocalAddr" // FastLeaseKeepAlive enables lease renewal to skip waiting for the applied index. // owner: @aaronjzhang // beta: v3.7 // main PR: https://github.com/etcd-io/etcd/pull/20589 FastLeaseKeepAlive featuregate.Feature = "FastLeaseKeepAlive" // PriorityRequest enables certain kinds of requests(e.g. LeaseRevoke) having higher priority to be applied under overload conditions. // owner: @silentred // alpha: v3.7 // main PR: https://github.com/etcd-io/etcd/pull/20492 PriorityRequest featuregate.Feature = "PriorityRequest" )
Variables ¶
var DefaultEtcdServerFeatureGates = map[featuregate.Feature]featuregate.FeatureSpec{ StopGRPCServiceOnDefrag: {Default: false, PreRelease: featuregate.Alpha}, InitialCorruptCheck: {Default: false, PreRelease: featuregate.Alpha}, CompactHashCheck: {Default: false, PreRelease: featuregate.Alpha}, TxnModeWriteWithSharedBuffer: {Default: true, PreRelease: featuregate.Beta}, LeaseCheckpoint: {Default: false, PreRelease: featuregate.Alpha}, LeaseCheckpointPersist: {Default: false, PreRelease: featuregate.Alpha}, SetMemberLocalAddr: {Default: false, PreRelease: featuregate.Alpha}, FastLeaseKeepAlive: {Default: true, PreRelease: featuregate.Beta}, PriorityRequest: {Default: false, PreRelease: featuregate.Alpha}, }
Functions ¶
func NewDefaultServerFeatureGate ¶
func NewDefaultServerFeatureGate(name string, lg *zap.Logger) featuregate.FeatureGate
Source Files ¶
etcd_features.go
- Version
- v3.7.1 (latest)
- Published
- Jul 23, 2026
- Platform
- linux/amd64
- Imports
- 3 packages
- Last checked
- 4 hours ago –
Tools for package owners.